<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>AddChannelsDialog</name>
    <message>
        <location filename="addchannelsdialog.ui" line="33"/>
        <source>Fixture Mode Channels Editor</source>
        <translation>Editor de canais Modo Fixture</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="114"/>
        <source>Available channels</source>
        <oldsource>All channels</oldsource>
        <translation>Canais disponíveis</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="106"/>
        <location filename="addchannelsdialog.ui" line="135"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="addchannelsdialog.ui" line="121"/>
        <source>Mode channels</source>
        <translation>Modo dos canais</translation>
    </message>
</context>
<context>
    <name>App</name>
    <message>
        <location filename="app.cpp" line="122"/>
        <source>Unrecognized file extension: %1</source>
        <translation>Extensão de ficheiro desconhecida: %1</translation>
    </message>
    <message>
        <location filename="app.cpp" line="150"/>
        <source>Fixture loading failed</source>
        <translation>Falha a carregar Fixture</translation>
    </message>
    <message>
        <location filename="app.cpp" line="151"/>
        <source>Unable to load fixture definition: </source>
        <translation>Não é possível carregar definições de fixture:</translation>
    </message>
    <message>
        <location filename="app.cpp" line="245"/>
        <source>&amp;New</source>
        <translation>&amp;Novo</translation>
    </message>
    <message>
        <location filename="app.cpp" line="246"/>
        <source>CTRL+N</source>
        <comment>File|New</comment>
        <translation>CTRL+N</translation>
    </message>
    <message>
        <location filename="app.cpp" line="251"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="app.cpp" line="252"/>
        <source>CTRL+O</source>
        <comment>File|Open</comment>
        <translation>CTRL+O</translation>
    </message>
    <message>
        <location filename="app.cpp" line="257"/>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <location filename="app.cpp" line="258"/>
        <source>CTRL+S</source>
        <comment>File|Save</comment>
        <translation>CTRL+S</translation>
    </message>
    <message>
        <location filename="app.cpp" line="263"/>
        <source>Save &amp;As...</source>
        <translation>Guardar &amp;como...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="264"/>
        <source>CTRL+SHIFT+S</source>
        <comment>File|Save As...</comment>
        <translation>CTRL+SHIFT+S</translation>
    </message>
    <message>
        <location filename="app.cpp" line="269"/>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <location filename="app.cpp" line="270"/>
        <source>CTRL+Q</source>
        <comment>File|Quit</comment>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <location filename="app.cpp" line="276"/>
        <source>Index</source>
        <translation>Índice</translation>
    </message>
    <message>
        <location filename="app.cpp" line="277"/>
        <source>SHIFT+F1</source>
        <comment>Help|Index</comment>
        <translation>SHIFT+F1</translation>
    </message>
    <message>
        <location filename="app.cpp" line="282"/>
        <source>About Fixture Definition Editor...</source>
        <translation>Sobre o Editor de Definições de Fixture...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="287"/>
        <source>About Qt...</source>
        <translation>Sobre QT...</translation>
    </message>
    <message>
        <location filename="app.cpp" line="314"/>
        <source>&amp;File</source>
        <translation>&amp;Ficheiro</translation>
    </message>
    <message>
        <location filename="app.cpp" line="324"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="app.cpp" line="362"/>
        <source>Open a fixture definition</source>
        <translation>Abrir definição de fixture</translation>
    </message>
</context>
<context>
    <name>CapabilityWizard</name>
    <message>
        <location filename="capabilitywizard.ui" line="33"/>
        <source>Capability Wizard</source>
        <translation>Asistente de Capacidades</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="39"/>
        <source>Values</source>
        <translation>Valores</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="45"/>
        <source>Start</source>
        <translation>Início</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="52"/>
        <source>The starting DMX value</source>
        <translation>Valor DMX inicial</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="62"/>
        <source>Width</source>
        <translation type="unfinished">Largura</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="69"/>
        <source>Number of values per capability</source>
        <translatorcomment>não soa bem</translatorcomment>
        <translation>Quantidade de valores por capacidade </translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="85"/>
        <source>Amount</source>
        <translation>Quantidade</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="92"/>
        <source>Number of capabilities to create</source>
        <translation>Quantidade de capacidades a criar</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="108"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="114"/>
        <source>The common base name for all capabilities. Use hash &apos;#&apos; to create a running number.</source>
        <translation>O nome comum para todas as capacidades. Utilize cardinal (#) para criar números consecutivos.</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="117"/>
        <source>Capability #</source>
        <translation>Capacidades #</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="127"/>
        <source>Sample</source>
        <translation>Exemplo</translation>
    </message>
    <message>
        <location filename="capabilitywizard.ui" line="133"/>
        <source>A list of capabilities that would be created with these settings</source>
        <translation>Lista de capacidades que serão criadas com estes parâmetros</translation>
    </message>
</context>
<context>
    <name>EditChannel</name>
    <message>
        <location filename="editchannel.ui" line="33"/>
        <source>Edit Channel</source>
        <translation>Editor de Canal</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="114"/>
        <source>&lt;font color=&quot;red&quot;&gt;&lt;b&gt;Capability overlapping detected. Please fix.&lt;/b&gt;&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="198"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="240"/>
        <source>Default value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="253"/>
        <source>Type</source>
        <translation type="unfinished">Tipo</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="260"/>
        <location filename="editchannel.ui" line="303"/>
        <source>Preset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="267"/>
        <source>The name of this channel</source>
        <translation>Nome deste canal</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="274"/>
        <source>Role</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="336"/>
        <source>Color 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="360"/>
        <source>Color 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="387"/>
        <source>Value 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="401"/>
        <source>Value 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="430"/>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="227"/>
        <source>The group this channel belongs to</source>
        <translation>O grupo a que pertence este canal</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="322"/>
        <source>Picture</source>
        <translation type="unfinished">Imagem</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="283"/>
        <source>Coarse (MSB)</source>
        <translation>Grosso (MSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="290"/>
        <source>Fine (LSB)</source>
        <translation>Fino (LSB)</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="55"/>
        <source>Capabilities</source>
        <translation>Capacidades</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="90"/>
        <location filename="editchannel.cpp" line="571"/>
        <source>Minimum value</source>
        <translation>Valor Mínimo</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="95"/>
        <location filename="editchannel.cpp" line="571"/>
        <source>Maximum value</source>
        <translation>Valor Máximo</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="100"/>
        <location filename="editchannel.cpp" line="571"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="154"/>
        <source>Remove the selected capability</source>
        <translation>Remover a capacidade seleccionada</translation>
    </message>
    <message>
        <location filename="editchannel.ui" line="121"/>
        <source>Capability wizard</source>
        <translation>Asistente de Capacidades</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="92"/>
        <source>Edit Channel: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="480"/>
        <source>Overlapping values</source>
        <translation>Subreposição de valores</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="497"/>
        <source>Open Gobo File</source>
        <translation type="unfinished">Abrir ficheiro de Gobos</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="500"/>
        <source>Gobo pictures</source>
        <translation type="unfinished">Imagens de gobos</translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="614"/>
        <source>Missing resources</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="615"/>
        <source>Some gobos are missing:

</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editchannel.cpp" line="481"/>
        <source>Some capabilities could not be created because of overlapping values.</source>
        <translation>Algumas capacidades não podem ser criadas devido a uma sobreposição de valores.</translation>
    </message>
</context>
<context>
    <name>EditHead</name>
    <message>
        <location filename="edithead.ui" line="33"/>
        <source>Edit Head</source>
        <translation>Editar cabeçalho</translation>
    </message>
    <message>
        <location filename="edithead.ui" line="52"/>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <location filename="edithead.ui" line="57"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
</context>
<context>
    <name>EditMode</name>
    <message>
        <location filename="editmode.ui" line="33"/>
        <source>Edit Mode</source>
        <translation>Editor de Modo</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="39"/>
        <source>Mode Name</source>
        <translation>Nome do Modo</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="53"/>
        <source>Channels</source>
        <translation>Canais</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="161"/>
        <source>Number</source>
        <translation>Número</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="166"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="79"/>
        <source>Add channel(s) to this mode</source>
        <translation>Adicionar canal(is) a este modo</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="59"/>
        <source>Remove the selected channel</source>
        <translation>Remover o canal seleccionado</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="99"/>
        <source>Raise the selected channel</source>
        <translation>Subir o canal seleccionado </translation>
    </message>
    <message>
        <location filename="editmode.ui" line="119"/>
        <source>Lower the selected channel</source>
        <translation>Baixar o canal seleccionado </translation>
    </message>
    <message>
        <location filename="editmode.ui" line="171"/>
        <source>Acts On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editmode.ui" line="193"/>
        <source>Heads</source>
        <translation>Cabeças</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="206"/>
        <source>Head</source>
        <translation>Cabeça</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="214"/>
        <source>Compose a new head</source>
        <translation>Compor nova cabeça</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="234"/>
        <source>Remove the selected head</source>
        <translation>Remover a cabeça seleccionada </translation>
    </message>
    <message>
        <location filename="editmode.ui" line="254"/>
        <source>Edit the channels that belong to the selected head</source>
        <translation>Editar os canais que pertencem à cabeça seleccionada </translation>
    </message>
    <message>
        <location filename="editmode.ui" line="274"/>
        <source>Raise the selected head</source>
        <translation>Subir a cabeça seleccionada </translation>
    </message>
    <message>
        <location filename="editmode.ui" line="294"/>
        <source>Lower the selected head</source>
        <translation>Baixar a cabeça seleccionada</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="328"/>
        <source>Physical</source>
        <translation>Físico</translation>
    </message>
    <message>
        <location filename="editmode.ui" line="338"/>
        <source>Use global settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editmode.ui" line="348"/>
        <source>Override global settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditPhysical</name>
    <message>
        <location filename="editphysical.ui" line="277"/>
        <source>Bulb</source>
        <translation>Lâmpada</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="45"/>
        <location filename="editphysical.ui" line="283"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="515"/>
        <source>Lumens</source>
        <translation>Lumens</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="535"/>
        <source>Colour Temp (K)</source>
        <translation>Temperatura de Cor (K) </translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="708"/>
        <source>Dimensions</source>
        <translation>Dimensões</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="784"/>
        <source>Weight</source>
        <translation>Peso</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="714"/>
        <source>kg</source>
        <translation>Kg</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="724"/>
        <source>Width</source>
        <translation>Largura</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="734"/>
        <location filename="editphysical.ui" line="754"/>
        <location filename="editphysical.ui" line="774"/>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="744"/>
        <source>Height</source>
        <translation>Altura</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="764"/>
        <source>Depth</source>
        <translation>Profundidade</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="39"/>
        <source>Head(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="630"/>
        <source>Lens</source>
        <translation>Lente</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="636"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="665"/>
        <source>Min Degrees</source>
        <translation>Graus Min</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="672"/>
        <source>Max Degrees</source>
        <translation>Graus Max</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="79"/>
        <source>Pan Max Degrees</source>
        <translation>Graus max Pan</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="96"/>
        <source>Tilt Max Degrees</source>
        <translation>Graus max Tilt</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="113"/>
        <source>Layout
(Columns x Rows)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="158"/>
        <source>Electrical</source>
        <translation>Eléctrico</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="164"/>
        <source>Power Consumption</source>
        <translation>Consumo eléctrico</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="174"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="184"/>
        <source>DMX Connector</source>
        <translation>Conector DMX</translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="241"/>
        <source>Copy physical information to clipboard</source>
        <translation>Copiar informação física para a área de transferência </translation>
    </message>
    <message>
        <location filename="editphysical.ui" line="258"/>
        <source>Paste physical information from clipboard</source>
        <translation>Colar informação física para a área de transferência </translation>
    </message>
</context>
<context>
    <name>FixtureEditor</name>
    <message>
        <location filename="fixtureeditor.ui" line="33"/>
        <source>Fixture</source>
        <translation>Fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="43"/>
        <source>General</source>
        <translation>Geral </translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="55"/>
        <source>Manufacturer</source>
        <translation>Fabricante</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="68"/>
        <source>The manufacturer name for this fixture (e.g. Martin)</source>
        <translation>O nome do fabricante deste fixture (ex.:Martin) </translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="75"/>
        <source>Model</source>
        <translation>Modelo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="88"/>
        <source>The model name for this fixture (e.g. MAC250)</source>
        <translation>O modelo deste fixture (ex.:MAC250) </translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="95"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="108"/>
        <source>The general type of this fixture</source>
        <translation>O tipo genérico deste fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="247"/>
        <source>Author</source>
        <translation>Autor</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="254"/>
        <source>The name of the author of this fixture definition</source>
        <oldsource>The author name of this fixture definition</oldsource>
        <translation>Nome do autor desta definição de fixture </translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="298"/>
        <location filename="fixtureeditor.ui" line="498"/>
        <source>Channels</source>
        <translation>Canais </translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="320"/>
        <location filename="fixtureeditor.ui" line="493"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="325"/>
        <source>Group</source>
        <translation>Grupo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="333"/>
        <source>Add a channel</source>
        <translation>Adicionar um canal </translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="353"/>
        <source>Remove the selected channel</source>
        <translation>Eliminar o canal seleccionado </translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="373"/>
        <source>Edit the selected channel</source>
        <translation>Editar o canal seleccionado </translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="400"/>
        <source>Copy the selected channel to the clipboard</source>
        <translation>Copiar o canal seleccionado para a área de transferência</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="420"/>
        <source>Paste the channel in clipboard to this fixture</source>
        <translation>Colar o canal na área de transferência neste fixture </translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="453"/>
        <source>Open/close all channel items</source>
        <translation>Abrir/Fechar todos os elementos do canal </translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="474"/>
        <source>Modes</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="503"/>
        <source>Heads</source>
        <translation>Cabeças</translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="511"/>
        <source>Add a mode</source>
        <translation>Adicionar um  modo </translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="531"/>
        <source>Remove the selected mode</source>
        <translation>Eliminar o  modo seleccionado </translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="551"/>
        <source>Edit the selected mode</source>
        <translation>Editar o modo seleccionado </translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="578"/>
        <source>Create a copy of the selected mode</source>
        <translation>Criar uma cópia do modo seleccionado </translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="611"/>
        <source>Open/close all mode items</source>
        <translation>Abrir/Fechar todos os elementos do modo </translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="632"/>
        <source>Aliases</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="650"/>
        <source>In mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="667"/>
        <source>Add a new alias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="687"/>
        <source>with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="694"/>
        <source>replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="711"/>
        <location filename="fixtureeditor.ui" line="764"/>
        <source>Alias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="716"/>
        <source>Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="721"/>
        <source>Base channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="726"/>
        <source>Override channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="744"/>
        <source>Remove the currently selected alias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fixtureeditor.ui" line="275"/>
        <source>Physical</source>
        <translation type="unfinished">Físico</translation>
    </message>
</context>
<context>
    <name>QLCFixtureEditor</name>
    <message>
        <location filename="fixtureeditor.cpp" line="206"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="207"/>
        <source>Do you want to save changes to fixture
&quot;%1&quot;
before closing?</source>
        <translation>¿Deseja guardar as alterações do fixture
&quot;%1&quot;
antes de fechar? </translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="236"/>
        <location filename="fixtureeditor.cpp" line="246"/>
        <source>Missing important information</source>
        <translation>Falta informação importante </translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="237"/>
        <source>Missing manufacturer name.
Unable to save fixture.</source>
        <translation>Falta o nome do fabricante.
Não se pode guardar o fixture. </translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="247"/>
        <source>Missing fixture model name.
Unable to save fixture.</source>
        <translation>Falta o nome do modelo de fixture.
Não se pode guardar o fixture.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="277"/>
        <location filename="fixtureeditor.cpp" line="336"/>
        <source>Fixture saving failed</source>
        <translation>Falha ao guardar Fixture </translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="278"/>
        <location filename="fixtureeditor.cpp" line="337"/>
        <source>Unable to save fixture definition:
%1</source>
        <oldsource>Unable to save fixture definition: </oldsource>
        <translation>Incapaz de se guardar as definições do fixture:
%1 </translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="293"/>
        <source>Save fixture definition</source>
        <translation>Guardaras definições de fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="370"/>
        <source>New Fixture</source>
        <translation>Novo Fixture</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="447"/>
        <location filename="fixtureeditor.cpp" line="545"/>
        <source>Channel already exists</source>
        <translation>Canal já existe</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="448"/>
        <location filename="fixtureeditor.cpp" line="546"/>
        <source>A channel by the name &quot;%1&quot; already exists!</source>
        <translation>O canal com o nome &quot;%1&quot; já existe!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="455"/>
        <location filename="fixtureeditor.cpp" line="552"/>
        <source>Channel has no name</source>
        <translation>O canal não tem nome</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="456"/>
        <location filename="fixtureeditor.cpp" line="553"/>
        <source>You must give the channel a descriptive name!</source>
        <translation>Tem de dar um nome descritivo ao canal!</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="493"/>
        <source>Are you sure you wish to remove channel: %1?</source>
        <translation>Tem a certezaque pretende remover o canal: %1 ?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="824"/>
        <source>Are you sure you wish to remove mode: %1?</source>
        <translation>Tem a certeza que pretende eliminar o modo: %1 ?</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="665"/>
        <location filename="fixtureeditor.cpp" line="700"/>
        <location filename="fixtureeditor.cpp" line="937"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="666"/>
        <location filename="fixtureeditor.cpp" line="702"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="667"/>
        <location filename="fixtureeditor.cpp" line="704"/>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="668"/>
        <location filename="fixtureeditor.cpp" line="706"/>
        <location filename="fixtureeditor.cpp" line="943"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="679"/>
        <source>Channels</source>
        <translation>Canais</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="777"/>
        <location filename="fixtureeditor.cpp" line="786"/>
        <source>Unable to add mode</source>
        <translation>Incapaz de adicionar modo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="778"/>
        <source>Another mode by that name already exists</source>
        <translation>Já existe outro modo com esse nome</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="787"/>
        <source>You must give a name to the mode</source>
        <translation>Tem de atribuir um nome ao modo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="823"/>
        <source>Remove Mode</source>
        <translation>Eliminar modo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="883"/>
        <source>Rename new mode</source>
        <translation>Renomear o novo modo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="884"/>
        <source>Give a unique name for the mode</source>
        <translation>Atribua um nome único ao modo</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="886"/>
        <source>Copy of %1</source>
        <translation>Cópia de %1</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="896"/>
        <source>Invalid name</source>
        <translation>Nome inválido</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="897"/>
        <source>Another mode by that name already exists.</source>
        <translation>Já existeoutro modo com esse nome.</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="940"/>
        <source>Clone</source>
        <translation>Clonar</translation>
    </message>
    <message>
        <location filename="fixtureeditor.cpp" line="948"/>
        <source>Modes</source>
        <translation>Modos</translation>
    </message>
</context>
</TS>
